@@ -126,13 +126,17 @@ CEXCEL_RETTYPE cexcel_biff_bof( cexcel_record_t * record,
         sl4_string_erase( sname, pos, sl4_string_length( sname ) - pos );
       }
       ctx->global_btype = btype;
-      cexcel_context_add_sheet( ctx, record->offset,
+      cexcel_context_sheet_add( ctx, record->offset,
                                 sl4_string_get( sname ) );
       sl4_string_delete( sname );
     }
-    if ( cexcel_context_get_sheet( ctx, record->offset ) ) {
+    if ( cexcel_context_sheet_get( ctx, record->offset ) ) {
       return CEXCEL_RETTYPE_BADFILE;
     }
   }
+  if ( ctx->sheet_btype == CEXCEL_BTYPE_BIFF5 ||
+       ctx->sheet_btype == CEXCEL_BTYPE_BIFF8 ) {
+    cexcel_context_format_init( ctx );
+  }
   return CEXCEL_RETTYPE_SUCCESS;
 }
