@@ -71,6 +71,8 @@ typedef long double CEXCEL_DOUBLE;
 #define CEXCEL_ID_CONTINUE    0x003c
 #define CEXCEL_ID_EOF         0x000a
 #define CEXCEL_ID_FILEPASS    0x002f
+#define CEXCEL_ID_FORMAT23    0x001e
+#define CEXCEL_ID_FORMAT458   0x041e
 #define CEXCEL_ID_INTEGER     0x0002
 #define CEXCEL_ID_LABEL2      0x0004
 #define CEXCEL_ID_LABEL3458   0x0204
@@ -82,6 +84,10 @@ typedef long double CEXCEL_DOUBLE;
 #define CEXCEL_ID_RK          0x027e
 #define CEXCEL_ID_RSTRING     0x00d6
 #define CEXCEL_ID_SST         0x00fc
+#define CEXCEL_ID_XF2         0x0043
+#define CEXCEL_ID_XF3         0x0243
+#define CEXCEL_ID_XF4         0x0443
+#define CEXCEL_ID_XF58        0x00e0
 /* iconv.c */
 const char *cexcel_iconv_codepage2charset( CEXCEL_WORD codepage );
 void cexcel_iconv_macja2cp932( sl4_string_t *str );
@@ -136,6 +142,27 @@ int cexcel_stream_seek( cexcel_file_t * file, off_t offset,
                         CEXCEL_SEEK_FLAG whence );
 int cexcel_stream_eof( cexcel_file_t * file );
 
+/* xf.c */
+typedef enum _CEXCEL_XFTYPE {
+  CEXCEL_XFTYPE_UNDEF = -1,
+  CEXCEL_XFTYPE_CELL = 0,
+  CEXCEL_XFTYPE_STYLE = 1
+} CEXCEL_XFTYPE;
+
+typedef struct _cexcel_xf_t {
+  CEXCEL_XFTYPE type;           /* xf type */
+  CEXCEL_UCHAR attrib;          /* attibutes used from parent style xf */
+  CEXCEL_DWORD idx_pstyle;      /* index of parent style xf */
+  CEXCEL_DWORD idx_font;        /* index of font */
+  CEXCEL_DWORD idx_format;      /* index of format */
+} cexcel_xf_t;
+
+cexcel_xf_t *cexcel_xf_new(  );
+int cexcel_xf_delete( cexcel_xf_t * xf );
+
+/* format.c */
+sl4_string_t *cexcel_format_double( double data, sl4_string_t *format );
+
 /* context.c */
 typedef enum _CEXCEL_BTYPE {
   CEXCEL_BTYPE_UNDEF,
@@ -152,7 +179,9 @@ typedef struct _cexcel_context_t {
   CEXCEL_WORD codepage;
   cexcel_file_t *file;
   int has_global;
+  sl4_hash_table_t *format;
   sl4_hash_table_t *sst;
+  sl4_hash_table_t *xf;
   sl4_hash_table_t *sheet;
   cexcel_book_t *book;
   cexcel_sheet_t *worksheet;
@@ -160,12 +189,38 @@ typedef struct _cexcel_context_t {
 
 cexcel_context_t *cexcel_context_new( cexcel_file_t * file );
 int cexcel_context_delete( cexcel_context_t * ctx );
-int cexcel_context_add_sst( cexcel_context_t * ctx, sl4_string_t *str );
-int cexcel_context_add_sheet( cexcel_context_t * ctx,
-                              CEXCEL_DWORD position, const char *str );
-int cexcel_context_get_sheet( cexcel_context_t * ctx, CEXCEL_DWORD position );
-sl4_string_t *cexcel_context_get_sst( cexcel_context_t * ctx,
-                                      CEXCEL_DWORD key );
+
+/* ctx_format.c */
+int cexcel_context_format_new( cexcel_context_t * ctx );
+int cexcel_context_format_delete( cexcel_context_t * ctx );
+int cexcel_context_format_init( cexcel_context_t * ctx );
+int cexcel_context_format_add( cexcel_context_t * ctx, CEXCEL_DWORD idx,
+                               sl4_string_t *str );
+sl4_string_t *cexcel_context_format_get( cexcel_context_t * ctx,
+                                         CEXCEL_DWORD idx );
+
+/* ctx_sst.c */
+int cexcel_context_sst_new( cexcel_context_t * ctx );
+int cexcel_context_sst_delete( cexcel_context_t * ctx );
+int cexcel_context_sst_add( cexcel_context_t * ctx, sl4_string_t *str );
+sl4_string_t *cexcel_context_sst_get( cexcel_context_t * ctx,
+                                      CEXCEL_DWORD idx );
+
+/* ctx_sheet.c */
+int cexcel_context_sheet_new( cexcel_context_t * ctx );
+int cexcel_context_sheet_delete( cexcel_context_t * ctx );
+int cexcel_context_sheet_add( cexcel_context_t * ctx, CEXCEL_DWORD position,
+                              const char *str );
+int cexcel_context_sheet_get( cexcel_context_t * ctx, CEXCEL_DWORD position );
+
+/* ctx_xf.c */
+int cexcel_context_xf_new( cexcel_context_t * ctx );
+int cexcel_context_xf_delete( cexcel_context_t * ctx );
+int cexcel_context_xf_add( cexcel_context_t * ctx, CEXCEL_XFTYPE type,
+                           CEXCEL_UCHAR attrib, CEXCEL_DWORD idx_pstyle,
+                           CEXCEL_DWORD idx_font, CEXCEL_DWORD idx_format );
+CEXCEL_DWORD cexcel_context_xf_get_format_index( cexcel_context_t * ctx,
+                                                 CEXCEL_DWORD idx );
 
 /* record.c */
 typedef enum _CEXCEL_STYPE {
@@ -202,10 +257,12 @@ sl4_string_t *cexcel_record_data_str( cexcel_record_t * record,
                                       size_t *offset, CEXCEL_STYPE stype,
                                       CEXCEL_SLEN slen );
 sl4_string_t *cexcel_record_data_rk( cexcel_record_t * record,
-                                     cexcel_context_t * ctx, size_t *offset );
+                                     cexcel_context_t * ctx, size_t *offset,
+                                     CEXCEL_DWORD idx_xf );
 void cexcel_record_align_word( CEXCEL_WORD * data );
 void cexcel_record_align_dword( CEXCEL_DWORD * data );
 int cexcel_record_word2int( CEXCEL_WORD data );
+int cexcel_record_dword2int( CEXCEL_DWORD data );
 double cexcel_record_dword2double( CEXCEL_DWORD high, CEXCEL_DWORD low );
 
 /* biff_blank.c */
@@ -229,6 +286,9 @@ CEXCEL_RETTYPE cexcel_biff_eof( cexcel_record_t * record,
 /* biff_filepass.c */
 CEXCEL_RETTYPE cexcel_biff_filepass( cexcel_record_t * record,
                                      cexcel_context_t * ctx );
+/* biff_format.c */
+CEXCEL_RETTYPE cexcel_biff_format( cexcel_record_t * record,
+                                   cexcel_context_t * ctx );
 /* biff_integer.c */
 CEXCEL_RETTYPE cexcel_biff_integer( cexcel_record_t * record,
                                     cexcel_context_t * ctx );
@@ -256,6 +316,9 @@ CEXCEL_RETTYPE cexcel_biff_rstring( cexcel_record_t * record,
 /* biff_sst.c */
 CEXCEL_RETTYPE cexcel_biff_sst( cexcel_record_t * record,
                                 cexcel_context_t * ctx );
+/* biff_xf.c */
+CEXCEL_RETTYPE cexcel_biff_xf( cexcel_record_t * record,
+                               cexcel_context_t * ctx );
 
 CEXCEL_END_DECLS
 #endif /* __CEXCEL_INTERNAL_H__ */
