@@ -30,8 +30,6 @@
 #include "cexcel.h"
 #include "cexcel_internal.h"
 
-static void _cexcel_context_sst_del_func( void *data, void *arg );
-
 cexcel_context_t *cexcel_context_new( cexcel_file_t * file )
 {
   cexcel_context_t *ctx;
@@ -50,16 +48,29 @@ cexcel_context_t *cexcel_context_new( cexcel_file_t * file )
     free( ctx );
     return NULL;
   }
-  ctx->sst = cexcel_hash_new(  );
-  if ( ctx->sst == NULL ) {
+  if ( cexcel_context_format_new( ctx ) != 0 ) {
     cexcel_book_delete( ctx->book );
     free( ctx );
     return NULL;
   }
-  ctx->sheet = cexcel_hash_new(  );
-  if ( ctx->sheet == NULL ) {
+  if ( cexcel_context_sst_new( ctx ) != 0 ) {
     cexcel_book_delete( ctx->book );
-    sl4_hash_table_delete( ctx->sst, _cexcel_context_sst_del_func, NULL );
+    cexcel_context_format_delete( ctx );
+    free( ctx );
+    return NULL;
+  }
+  if ( cexcel_context_xf_new( ctx ) != 0 ) {
+    cexcel_book_delete( ctx->book );
+    cexcel_context_format_delete( ctx );
+    cexcel_context_sst_delete( ctx );
+    free( ctx );
+    return NULL;
+  }
+  if ( cexcel_context_sheet_new( ctx ) != 0 ) {
+    cexcel_book_delete( ctx->book );
+    cexcel_context_format_delete( ctx );
+    cexcel_context_sst_delete( ctx );
+    cexcel_context_xf_delete( ctx );
     free( ctx );
     return NULL;
   }
@@ -69,51 +80,10 @@ cexcel_context_t *cexcel_context_new( cexcel_file_t * file )
 int cexcel_context_delete( cexcel_context_t * ctx )
 {
   /* cexcel_book_delete( ctx->book ); */
-  sl4_hash_table_delete( ctx->sheet, NULL, NULL );
-  sl4_hash_table_delete( ctx->sst, _cexcel_context_sst_del_func, NULL );
+  cexcel_context_sheet_delete( ctx );
+  cexcel_context_sst_delete( ctx );
+  cexcel_context_format_delete( ctx );
+  cexcel_context_xf_delete( ctx );
   free( ctx );
   return 0;
 }
-
-int cexcel_context_add_sst( cexcel_context_t * ctx, sl4_string_t *str )
-{
-  CEXCEL_DWORD nextkey = ( CEXCEL_DWORD ) ctx->sst->nkeys;
-  return sl4_hash_table_insert( ctx->sst, &nextkey, str );
-}
-
-sl4_string_t *cexcel_context_get_sst( cexcel_context_t * ctx,
-                                      CEXCEL_DWORD key )
-{
-  return ( sl4_string_t * ) sl4_hash_table_lookup( ctx->sst, &key );
-}
-
-int cexcel_context_add_sheet( cexcel_context_t * ctx, CEXCEL_DWORD offset,
-                              const char *str )
-{
-  cexcel_sheet_t *sheet;
-  sheet = cexcel_book_add_sheet( ctx->book, str );
-  if ( sheet == NULL ) {
-    return -1;
-  }
-  if ( sl4_hash_table_insert( ctx->sheet, &offset, sheet ) ) {
-    return -1;
-  }
-  return 0;
-}
-
-int cexcel_context_get_sheet( cexcel_context_t * ctx, CEXCEL_DWORD offset )
-{
-  cexcel_sheet_t *sheet;
-  sheet = ( cexcel_sheet_t * ) sl4_hash_table_lookup( ctx->sheet, &offset );
-  if ( sheet == NULL ) {
-    return -1;
-  }
-  ctx->worksheet = sheet;
-  return 0;
-}
-
-static void _cexcel_context_sst_del_func( void *data, void *arg )
-{
-  sl4_string_t *str = ( sl4_string_t * ) data;
-  sl4_string_delete( str );
-}
