@@ -73,11 +73,11 @@ int cexcel_record_read( cexcel_file_t * file, cexcel_record_t * record )
 void cexcel_record_dump( cexcel_record_t * record )
 {
   CEXCEL_WORD i;
-  printf( "RECORD: OFFSET(%08x), ID(%04x), LEN(%04d)", record->offset,
+  printf( "RECORD: OFFSET(%08lx), ID(%04x), LEN(%04d)", record->offset,
           record->id, record->len );
   for ( i = 0; i < record->len; i++ ) {
     if ( i % 16 == 0 ) {
-      printf( "\n%08x ", record->offset + i );
+      printf( "\n%08lx ", record->offset + i );
     }
     printf( " %02x", record->data[i] );
   }
@@ -144,10 +144,12 @@ CEXCEL_WORD cexcel_record_data_word( cexcel_record_t * record,
                                      cexcel_context_t * ctx, size_t *offset )
 {
   CEXCEL_WORD ret;
+  CEXCEL_WORD *ret_ref;
   CEXCEL_UCHAR c[2];
   c[0] = cexcel_record_data_uchar( record, ctx, offset );
   c[1] = cexcel_record_data_uchar( record, ctx, offset );
-  ret = *( ( CEXCEL_WORD * ) & c );
+  ret_ref = ( ( CEXCEL_WORD * ) & c );
+  ret = *ret_ref;
   return ret;
 }
 
@@ -156,12 +158,14 @@ CEXCEL_DWORD cexcel_record_data_dword( cexcel_record_t * record,
                                        size_t *offset )
 {
   CEXCEL_DWORD ret;
+  CEXCEL_DWORD *ret_ref;
   CEXCEL_UCHAR c[4];
   c[0] = cexcel_record_data_uchar( record, ctx, offset );
   c[1] = cexcel_record_data_uchar( record, ctx, offset );
   c[2] = cexcel_record_data_uchar( record, ctx, offset );
   c[3] = cexcel_record_data_uchar( record, ctx, offset );
-  ret = *( ( CEXCEL_DWORD * ) & c );
+  ret_ref = ( ( CEXCEL_DWORD * ) & c);
+  ret = *ret_ref;
   return ret;
 }
 
@@ -271,20 +275,22 @@ sl4_string_t *cexcel_record_data_str( cexcel_record_t * record,
 }
 
 sl4_string_t *cexcel_record_data_rk( cexcel_record_t * record,
-                                     cexcel_context_t * ctx, size_t *offset )
+                                     cexcel_context_t * ctx, size_t *offset,
+                                     CEXCEL_DWORD idx_xf )
 {
-  CEXCEL_DWORD value;
-  sl4_string_t *str;
+  CEXCEL_DWORD value, idx_format;
+  sl4_string_t *format;
   double data = 0.0;
-  int idata = 0, is_integer = 0;
   value = cexcel_record_data_dword( record, ctx, offset );
   cexcel_record_align_dword( &value );
+  idx_format = cexcel_context_xf_get_format_index( ctx, idx_xf );
+  format = cexcel_context_format_get( ctx, idx_format );
   if ( value & 0x00000001 ) {
     /* encoded value is multiplied by 100 */
     if ( value & 0x00000002 ) {
       /* signed integer */
       cexcel_record_align_dword( &value );
-      data = ( double ) cexcel_record_word2int( value >> 2 ) * 0.01;
+      data = ( double ) cexcel_record_dword2int( value >> 2 ) * 0.01;
     } else {
       /* floting point value */
       CEXCEL_DWORD high, low;
@@ -298,8 +304,7 @@ sl4_string_t *cexcel_record_data_rk( cexcel_record_t * record,
     if ( value & 0x00000002 ) {
       /* signed integer */
       cexcel_record_align_dword( &value );
-      idata = cexcel_record_word2int( value >> 2 );
-      is_integer = 1;
+      data = ( double ) cexcel_record_dword2int( value >> 2 );
     } else {
       /* floting point value */
       CEXCEL_DWORD high, low;
@@ -309,16 +314,7 @@ sl4_string_t *cexcel_record_data_rk( cexcel_record_t * record,
       data = cexcel_record_dword2double( high, low );
     }
   }
-  str = sl4_string_new( NULL );
-  if ( str == NULL ) {
-    return NULL;
-  }
-  if ( is_integer ) {
-    sl4_string_sprintf( str, "%d", idata );
-  } else {
-    sl4_string_sprintf( str, "%g", data );
-  }
-  return str;
+  return cexcel_format_double( data, format );
 }
 
 void cexcel_record_align_word( CEXCEL_WORD * data )
@@ -339,6 +335,14 @@ int cexcel_record_word2int( CEXCEL_WORD data )
   return ( int ) ret;
 }
 
+int cexcel_record_dword2int( CEXCEL_DWORD data )
+{
+  CEXCEL_DWORD ret;
+  ret = data;
+  _cexcel_record_align_endian( ( CEXCEL_UCHAR * ) & ret, 4 );
+  return ( int ) ret;
+}
+
 double cexcel_record_dword2double( CEXCEL_DWORD high, CEXCEL_DWORD low )
 {
   union {
@@ -413,7 +417,7 @@ static int _cexcel_record_read_continue( cexcel_record_t * record,
     *offset = 0;
   }
 #ifdef _CEXCEL_DEBUG_BIFF
-  printf( "%08x %03x CONTINUE - Length(%d)\n", record->offset, record->id,
+  printf( "%08lx %03x CONTINUE - Length(%d)\n", record->offset, record->id,
           record->len );
 #endif
   return 0;
