@@ -478,7 +478,7 @@ int __OLEdecode (const char *OLEfilename, pps_entry ** stream_list, U32 * root,
 #if defined( __WIN32__ ) || defined( __BORLANDC__ )
 	    *_sbfilename = (U8 *)malloc (TMPNAM_LEN);
 	    test_exitf (*_sbfilename != NULL, 10, ends ());
-	    tmpnam (*_sbfilename);
+	    __cole_tmpnam (*_sbfilename);
 	    test_exitf (*_sbfilename[0], 7, ends ());
 	    sbfile = OLEfile = fopen (*_sbfilename, "w+b");
 #else
@@ -509,7 +509,7 @@ int __OLEdecode (const char *OLEfilename, pps_entry ** stream_list, U32 * root,
 	{
 	    /* this branch is never executed now */
 #if defined( __WIN32__ ) || defined( __BORLANDC__ )
-		tmpnam (pps_list[i].filename);
+		__cole_tmpnam (pps_list[i].filename);
 		test_exitf (pps_list[i].filename[0], 7, ends ());
 		verbose(pps_list[i].name + (!isprint(pps_list[i].name[0]) ? 1 : 0));
 		OLEfile = fopen (pps_list[i].filename, "wb");
